@@ -1,9 +1,9 @@
+from datapac.config import Environment
 from datapac.package.package import Package
 from datapac.package.package import open as pkg_open
 from datapac.package.package import render
 from datapac.rcave.sources.postgres import source as postgres
 from datapac.rcave.sources.s3 import source as s3
-from datapac.utils.environment import Environment
 
 open = pkg_open
 
